oci

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ReadDirManifest

func ReadDirManifest(dir string) ([]byte, string, error)

ReadDirManifest reads <dir>/manifest.json and returns its raw bytes along with the manifest's declared media type.

It does not call into containers-image so it can be used during archive packing without opening an ImageSource.

Types

This section is empty.

Jump to