Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReadDirManifest ¶
ReadDirManifest reads <dir>/manifest.json and returns its raw bytes along with the manifest's declared media type.
It does not call into containers-image so it can be used during archive packing without opening an ImageSource.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.